<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>འཇུག་ཆས་%1དང་རྒྱུད་ཁོངས་ཀྱི་པར་གཞི་ཕན་ཚུན་མི་མཐུན་པ།</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>འཕུར་བའི་རྣམ་པ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>སོ་སྔོན་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>སོ་སྔོན་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>འཕུར་བའི་རྣམ་པ་ཁ་རྒྱག་པ།</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>འཕུར་སྐྱོད་དཔེ་རྣམ།</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>སྤོ་འབུད།</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>སོ་སྔོན་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>སོ་སྔོན་ཁ་རྒྱོབ།</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>སོ་སྔོན་ཁ་ཕྱེ།</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>སོ་སྔོན་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1མཐུད་ཟིན།</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>སྦྲེལ་བཞིན་པ། </translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>སོ་སྔོན།</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>སོ་སྔོན་ཁ་རྒྱོབ།</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>སོ་སྔོན།</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>མཐེབ་གཞོང་བཀོད་པ་སྣོན་པ།</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>དུས་ཚོད།</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>ཆུ་ཚོད་12ཀྱི་ལུགས།</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>ཆུ་ཚོད་24ཡི་ལུགས། </translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>དུས་ཚོད་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>གཟའ་ཟླ་བ།</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>གཟའ་མིག་དམར།</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>གཟའ་ལྷག་པ།</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>གཟའ་ཕུར་བུ།</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>གཟའ་པ་སངས།</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>གཟའ་སྤེན་པ།</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>གཟའ་ཉི་མ།</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>གཟའ་ཟླ་བ། </translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>wednesday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>thursday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>friday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>saturday</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sunday</source>
        <translation>གཟའ་ཉི་མ།</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>ཁྱོད་ཀྱིས་སྙིགས་སྣོད་ནང་གི་ནང་དོན་%1དག་གཙང་སེལ་བྱེད་རྒྱུ་ཡིན་པ་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>འདོར་བ། </translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>སུབ་པ།</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>བཀོལ་སྤྱོད་འདི་བྱས་ཚེ་སོར་ཆུད་ཐབས་བྲལ།</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>མ་ཤེས་པའི་སྒྲིག་ཆས།</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>ཤོང་ཚད་མ་ཤེས་པ།</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>སྡུད་སྡེར།</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ཁ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>ཚང་མ་བཤིག་འདོན་བྱེད།</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>འགོ་སློང་ཆས།</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>བདེ་འཇགས་དཔེ་རྣམ་ལས་ཕྱིར་དོན་པ།</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>ལས་འགན་ཚན་བྱང་གི་བདེ་འཇགས་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>ལས་འགན་ཚན་བྱང་བདེ་འཇགས་དཔེ་རྣམ་ནང་མཛུལ་ཟིན་པས། བདེ་འཇགས་དཔེ་རྣམ་ལས་ཕྱིར་དོན་རྗེས་རྒྱུན་ལྡན་ལྟར་ཤར་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>དར་སྲོལ་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>ལས་ཆོད་ཆེ་བའི་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>གོང་།</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>འོག</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>གཡོན།</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>གཡས།</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>རྟག་ཏུ་མངོན་སྟོན་བྱེད།</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>རྟག་ཏུ་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>རིག་ནུས་གབ་ཡིབ།</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>གནས་ས།</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>རྣམ་པ།</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>ལས་འགན་ཚན་བྱང་སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>ཆེ་ཆུང་།</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>བརྙན་མང་མངོན་སྟོན་སྒྲིག་འགོད།</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>ལྷུ་ལག་ཁུལ་ཁོངས།</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>ལས་འགན་ཚན་བྱང་གི་ལྷུ་ལག་ཁུལ་དུ་མངོན་པའི་པར་རིས་འདེམས་པ།</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>དར་སྲོལ་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>ལས་ཆོད་ཆེ་བའི་དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>དཔེ་རྣམ།</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>གོང་།</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>འོག</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>གཡོན།</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>གཡས།</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>གནས་ས།</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>རྟག་ཏུ་མངོན་པ།</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>རྟག་ཏུ་ཡིབ་པ།</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>རིག་ནུས་གབ་ཡིབ།</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>རྣམ་པ།</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>ཆུང་ངུ།</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>ཆེ་བ།</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>ལས་འགན་ཚན་བྱང་གི་གནས་ས།</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>ཙི་གུའི་གནས་ཡུལ་ལྟར་མངོན་པ།</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>བརྙན་ཡོལ་ཨ་མ་ཁོ་ན་མངོན་པ།</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>འགན་མང་མཐོང་རིས།</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>བསྡད་པ་གཙང་སེལ།</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>བརྙན་ཡོལ་མཐེབ་གཞོང་།</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>སྒྲིག་འགོད།</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>གློག་ཁུངས་དོ་དམ།</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>གློག་ཁུངས་སྒིག་འགོད།</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>གློག་ཚད་%1 སྐར་མ་%2ལྷག་འདུག</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>གློག་ཚད་%1 ཆུ་ཚོད་%2དང་སྐར་མ་%3ལྷག་འདུག</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད་%1 ད་དུང་སྐར་མ་%2དགོས།</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>གློག་གསོག་བཞིན་ཡོད་%1 ད་དུང་ཆུ་ཚོད་%2དང་སྐར་མ་%3དགོས།</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>གློག་ཚད་%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>གློག་གསོག་བཞིན་ཡོད་%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>གློག་ཚད་%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>གློག་ཚད་%1 ཁེངས་ཟིན།</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>ལས་འགན་ཚན་བྱང་།</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>དཔེ་རྣམ།</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>གནས་ས།</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>རྣམ་པ།</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>ཆེ་ཆུང་།</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>ལས་འགན་ཚན་བྱང་གི་གནས་ས།</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>ལྷུ་ལག་ཁུལ་ཁོངས།</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>མངོན་སྟོན་ཅོག་ངོས།</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>བསྡད་པ་གཙང་སེལ།</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>གློག་ཁུངས་དོ་དམ།</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>ཁ་བརྒྱབ།</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>སྒུག་སྡོད།</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>མལ་གསོ།</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>ཟྭ་རྒྱག</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>ཐོ་སུབ་པ།</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>རྩིས་ཁྲ་བརྗེ་བ།</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>གློག་ཁུངས་སྒིག་འགོད།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>སྒྲ་ལྡན།</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>སྒྲ་མེད།</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>སྐད་གདངས་སྒྲིག་འགོད།</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>མིག་སྔའི་སྐད་གདངས་%1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>སྒྲ།</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>སྙིགས་སྣོད།</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>སྙིགས་སྣོད་ཀྱི་ཡིག་ཆ་%1</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>སྙིགས་སྣོད་ཀྱི་ཡིག་ཆ་%1</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>སྙིགས་སྣོད་ནང་བླུགས་པ།</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>ཁ་ཕྱེ་བ།</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>གསལ་ཐོ་གཙང་སེལ།</translation>
    </message>
</context>
</TS>